#ifndef RFKFREADER_H
#define RFKFREADER_H

//#include "RFSReader.h"
#include "RFKReader.h"

class CRKFReader :
	public CRFKReader
{
public:
	CRKFReader(CReader *Owner, CBaseCommunication *Communicator);
	virtual ~CRKFReader(void);
	virtual void SetHWString(char *String);
	virtual void GetProductString(uint8_t *Product);
	//	virtual CJ_RESULT CtSetBacklight(EBacklight eBacklight,uint32_t *Result);	
	//	virtual CJ_RESULT CtSelfTest2(const uint8_t *TransportKey,uint8_t KeyNr);
	//protected:
	//#ifdef WITH_SECODER_INFO_OVERRIDE
	//	CJ_RESULT KTLightCall(uint8_t *sad, uint8_t *dad, uint8_t *cmd, uint16_t lenc, int32_t Lc, uint8_t *data_ptr, int32_t Le, uint8_t *response, uint16_t *lenr);
	//#endif

	virtual CJ_RESULT BuildReaderInfo();

private:
	void SetNFCSpeedLimit();

};

#endif


