#ifndef SH1READER_H
#define SH1READER_H

#include "SHUReader.h"

class CRS2Reader :
	public CSHUReader
{
public:
	CRS2Reader(CReader *Owner,CBaseCommunication *Communicator);
	virtual ~CRS2Reader(void);
	
	virtual void SetHWString(char *String);
	virtual void GetProductString(uint8_t *Product);
};

#endif

