#include "Platform.h"
#include <string.h>
#include <stdio.h>
#include <time.h>
#include "RS1Reader.h"
#include "BaseCommunication.h"

#include "memory_placements.h"


#define base CRFSReader

CRS1Reader::CRS1Reader(CReader *Owner, CBaseCommunication *Communicator)
	:base(Owner, Communicator)
{
}

CRS1Reader::~CRS1Reader(void)
{
}

void CRS1Reader::SetHWString(char *String)
{
	strcpy(String, "RS1_");
}

void CRS1Reader::GetProductString(uint8_t *Product)
{
	memcpy(Product, "CJRS1", 5);
}

