#ifndef SP1READER_H
#define SP1READER_H

#include "SPLReader.h"

class CRS3Reader :
	public CSPLReader
{
public:
	CRS3Reader(CReader *Owner, CBaseCommunication *Communicator);
	virtual ~CRS3Reader(void);
protected:
	virtual void SetHWString(char *String);
	virtual void GetProductString(uint8_t *Product);

};

#endif