#ifndef RSEREADER_H
#define RSEREADER_H

#include "RFSReader.h"

class CRSEReader :
	public CRFSReader
{
public:
	CRSEReader(CReader *Owner,CBaseCommunication *Communicator);
	virtual ~CRSEReader(void);
	
	virtual void SetHWString(char *String);
	virtual void GetProductString(uint8_t *Product);
};

#endif

