#include "Platform.h"
#include <string.h>
#include <stdio.h>
#include <time.h>
#include "SP1Reader.h"
#include "BaseCommunication.h"

#include "memory_placements.h"

#define base CSPLReader

CRS3Reader::CRS3Reader(CReader *Owner, CBaseCommunication *Communicator)
	:base(Owner, Communicator)
{
}

CRS3Reader::~CRS3Reader(void)
{
}

void CRS3Reader::SetHWString(char *String)
{
	strcpy(String, "RS3_");
}

void CRS3Reader::GetProductString(uint8_t *Product)
{
	memcpy(Product, "CJRS3", 5);
}
