#include "Platform.h"
#include <string.h>
#include <stdio.h>
#include <time.h>
#include "SH1Reader.h"
#include "BaseCommunication.h"

#include "memory_placements.h"


#define base CSHUReader

CRS2Reader::CRS2Reader(CReader *Owner,CBaseCommunication *Communicator)
			  :base(Owner,Communicator)
{
}

CRS2Reader::~CRS2Reader(void)
{
}

void CRS2Reader::SetHWString(char *String)
{
	strcpy(String,"RS2_");
}

void CRS2Reader::GetProductString(uint8_t *Product)
{
	memcpy(Product,"CJRS2",5);
}

