#ifndef RS1READER_H
#define RS1READER_H

#include "ECPReader.h"
#include <time.h>
#include "RFKReader.h"


class CRS1Reader :
	public CRFSReader
{
public:
	CRS1Reader(CReader *Owner, CBaseCommunication *Communicator);
	virtual ~CRS1Reader(void);


protected:
	virtual void SetHWString(char *String);
	virtual void GetProductString(uint8_t *Product);
};

#endif


